/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2002 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Contact: pascal.dechamboux@rd.francetelecom.com
 *
 * Authors: R. Basset, S. Chassande-Barrioz, P. Dechamboux, N. De Palma,
 *          A. Lefebvre, X. Spengler.
 *
 */

package org.objectweb.jorm.runtime.mapper.rdb.adapter.lib;

import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.jorm.type.api.PType;

import java.sql.ResultSet;
import java.sql.SQLException;

/*
 * @author	<A HREF="mailto:sebastien.chassande@inrialpes.fr><b>
 *			Sebastien Chassande-Barrioz
 *			</b></A>
 */

public class PostgresAdapter extends BasicRdbAdapter {

	public PostgresAdapter() {
		super();
	}

	public String getSqlType(PType pt, boolean usedInPK) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
		case PType.TYPECODE_OBJBOOLEAN:
			return "BOOL";
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
		case PType.TYPECODE_SHORT:
		case PType.TYPECODE_OBJSHORT:
			return "INT2";
		case PType.TYPECODE_INT:
		case PType.TYPECODE_OBJINT:
			return "INT4";
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
			return "INT8";
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_OBJFLOAT:
			return "FLOAT4";
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
			return "FLOAT8";
		case PType.TYPECODE_SERIALIZED:
			return "BYTEA";
		default:
			return super.getSqlType(pt, usedInPK);
		}
	}

	/**
	 * This calculates the size of a result set. If this feature is not supported
	 * by a database or its jdbc driver, this method returns 0.
	 * @ResultSet rs the result set which the size must be returned
	 */
	public int fetchResultSetSize(ResultSet rs) throws SQLException {
		return -1;
	}

    public String getSqlGetterName(PType pt, String resultSet, int idx)
        throws PExceptionProtocol {
        if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
        case PType.TYPECODE_OBJSHORT:
            return "new Short(" + resultSet + ".getShort(" + idx + "))";
        case PType.TYPECODE_OBJBYTE:
            return "new Byte(" + resultSet + ".getByte(" + idx + "))";
		default:
            return super.getSqlGetterName(pt, resultSet, idx);
        }
    }
/*
    public String getSqlSetterName(PType pt, String value, int idx) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
		default:
			return super.getSqlSetterName(pt, value, idx);
		}
	}
*/
}
