/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mapping are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2002 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Contact: pascal.dechamboux@rd.francetelecom.com
 *
 * Authors: R. Basset, S. Chassande-Barrioz, P. Dechamboux, N. De Palma,
 *          A. Lefebvre, X. Spengler.
 *
 */

package org.objectweb.jorm.runtime.mapper.rdb.adapter.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.api.PExceptionProtocol;

import java.sql.ResultSet;
import java.sql.SQLException;

/**
 * @author S.Chassande-Barrioz
 */
public class OracleAdapter extends BasicRdbAdapter {

    private int varcharSize = 1024;
    private int varcharSizeInPk = 256;

	public OracleAdapter() {
		super();
	}

	public void setVarcharSize(int s) {
		varcharSize = s;
	}

	public void setVarcharSizeInPk(int s) {
		varcharSizeInPk = s;
	}

	public String getSqlType(PType pt, boolean usedInPK) throws PExceptionProtocol {
		if (pt == null) {
			throw new PExceptionProtocol("No Sql Type name associated to a null PType");
		}
		switch (pt.getTypeCode()) {
		case PType.TYPECODE_BOOLEAN:
		case PType.TYPECODE_OBJBOOLEAN:
		case PType.TYPECODE_BYTE:
		case PType.TYPECODE_OBJBYTE:
		case PType.TYPECODE_SHORT:
		case PType.TYPECODE_OBJSHORT:
		case PType.TYPECODE_LONG:
		case PType.TYPECODE_OBJLONG:
		case PType.TYPECODE_DOUBLE:
		case PType.TYPECODE_OBJDOUBLE:
		case PType.TYPECODE_BIGDECIMAL:
            return "NUMBER";
		case PType.TYPECODE_STRING:
			return (usedInPK
				? "VARCHAR(" + varcharSizeInPk + ")"
				: "VARCHAR(" + varcharSize + ")");
		case PType.TYPECODE_SERIALIZED:
			return "BLOB";
		default:
			return super.getSqlType(pt, usedInPK);
		}
	}

    public String getSqlGetterName(PType pt, String resultSet, int idx)
        throws PExceptionProtocol {
        if (pt == null) {
			throw new PExceptionProtocol("Invalid parameter");
		}
		switch (pt.getTypeCode()) {
        case PType.TYPECODE_OBJBYTE:
            return "new Byte(" + resultSet + ".getByte(" + idx + "))";
        case PType.TYPECODE_OBJSHORT:
            return "new Short(" + resultSet + ".getShort(" + idx + "))";
        case PType.TYPECODE_OBJINT:
            return "new Integer(" + resultSet + ".getInt(" + idx + "))";
		default:
            return super.getSqlGetterName(pt, resultSet, idx);
        }
    }

}
